@@ -3,10 +3,15 @@ from sqlalchemy import create_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy_continuum import (
-    Versioned, versioned_session, configure_versioned
+    Versioned,
+    versioned_session,
+    make_versioned
 )
 
 
+make_versioned(sa.orm.mapper)
+
+
 class TestCase(object):
     inspect_column_order = False
 
@@ -20,10 +25,6 @@ class TestCase(object):
 
         self.create_models()
 
-        sa.event.listen(
-            sa.orm.mapper, 'after_configured', configure_versioned
-        )
-
         sa.orm.configure_mappers()
         if hasattr(self, 'Article'):
             self.ArticleHistory = self.Article.__versioned__['class']
